"""APP1 segment hexadecimal baseline for test_modify."""

from baseline import Baseline

LITTLE_ENDIAN_MODIFY_BASELINE = Baseline("""
    FFE101D645786966000049492A000800000009000F0102000D0000007A000000100102000E000000880000001A
    01050001000000960000001B010500010000009E00000028010300010000000200000013020300010000000200
    00001402050006000000A60000006987040001000000D600000025880400010000005C01000000000000455849
    46205061636B61676500004d6f646966696564000000000000C800000001000000C80000000100000000000000
    01000000FF000000010000008000000001000000FF000000010000008000000001000000FF0000000100000009
    0000900700040000003032323003900200140000004801000001910700040000000102030000A0070004000000
    3031303001A00300010000000100000002A0030001000000D803000003A00300010000006505000009A4030001
    000000010000000AA40300010000000100000000000000323031393A30323A30382032313A34343A3335000500
    00000100040000000203000001000200020000005300000002000500030000009E010000030002000200000057
    0000000400050003000000B6010000000000004F000000010000002400000001000000B96B0100A30600000c00
    0000010000002200000001000000d5dd0000e8030000FFDB
    """)
